==> v7.2.x.zip: nucypher/README.md <==
![](nucypher.png)

*Cryptographic primitives, hosted on the decentralized nodes of the Threshold network, offering accessible, intuitive, and extensible runtimes and interfaces for
secrets management and dynamic access control.*

[![pypi](https://img.shields.io/pypi/v/nucypher.svg?style=flat)](https://pypi.org/project/nucypher/)
[![pyversions](https://img.shields.io/pypi/pyversions/nucypher.svg)](https://pypi.org/project/nucypher/)
[![codecov](https://codecov.io/gh/nucypher/nucypher/branch/development/graph/badge.svg?token=9w1dAFqog5)](https://codecov.io/gh/nucypher/nucypher)
[![discord](https://img.shields.io/discord/411401661714792449.svg?logo=discord)](https://discord.gg/7rmXa3S)
[![license](https://img.shields.io/pypi/l/nucypher.svg)](https://www.gnu.org/licenses/gpl-3.0.html)

----

# TACo Access Control

TACo (Threshold Access Control) is end-to-end encrypted data sharing and communication, without the requirement of
trusting a centralized authority, who might unilaterally deny service or even decrypt private user data. It is the only
access control layer available to Web3 developers that can offer a decentralized service, through a live,
well-collateralized and battle-tested network.  See more here: [https://docs.threshold.network/applications/threshold-access-control](https://docs.threshold.network/applications/threshold-access-control)

# Getting Involved

NuCypher is a community-driven project and we're very open to outside contributions.

All our development discussions happen in our [Discord server](https://discord.gg/7rmXa3S), where we're happy to answer
technical questions, discuss feature requests,
and accept bug reports.

If you're interested in contributing code, please check out
our [Contribution Guide](CONTRIBUTING.rst)
and browse our [Open Issues](https://github.com/nucypher/nucypher/issues) for potential areas to contribute.

# Security

If you identify vulnerabilities with _any_ nucypher code, please email security@nucypher.com with relevant information
to your findings.
We will work with researchers to coordinate vulnerability disclosure between our stakers, partners, and users to ensure
successful mitigation of vulnerabilities.

Throughout the reporting process, we expect researchers to honor an embargo period that may vary depending on the
severity of the disclosure.
This ensures that we have the opportunity to fix any issues, identify further issues (if any), and inform our users.

Sometimes vulnerabilities are of a more sensitive nature and require extra precautions.
We are happy to work together to use a more secure medium, such as Signal.
Email security@nucypher.com and we will coordinate a communication channel that we're both comfortable with.

A great place to begin your research is by working on our testnet.
Please see our [documentation](https://docs.threshold.network) to get started.
We ask that you please respect testnet machines and their owners.
If you find a vulnerability that you suspect has given you access to a machine against the owner's permission, stop what
you're doing and immediately email security@nucypher.com.

==> v7.3.x.zip: nucypher/README.md <==
![](nucypher.png)

*Cryptographic primitives, hosted on the decentralized nodes of the Threshold network, offering accessible, intuitive, and extensible runtimes and interfaces for
secrets management and dynamic access control.*

[![pypi](https://img.shields.io/pypi/v/nucypher.svg?style=flat)](https://pypi.org/project/nucypher/)
[![pyversions](https://img.shields.io/pypi/pyversions/nucypher.svg)](https://pypi.org/project/nucypher/)
[![codecov](https://codecov.io/gh/nucypher/nucypher/branch/development/graph/badge.svg?token=9w1dAFqog5)](https://codecov.io/gh/nucypher/nucypher)
[![discord](https://img.shields.io/discord/411401661714792449.svg?logo=discord)](https://discord.gg/7rmXa3S)
[![license](https://img.shields.io/pypi/l/nucypher.svg)](https://www.gnu.org/licenses/gpl-3.0.html)

----

# Threshold Access Control (TACo)

TACo is end-to-end encrypted data sharing and communication, without the requirement of
trusting a centralized authority, who might unilaterally deny service or even decrypt private user data. It is the only
access control layer available to Web3 developers that can offer a decentralized service, through a live,
well-collateralized and battle-tested network.  See more here: [https://docs.threshold.network/applications/threshold-access-control](https://docs.threshold.network/applications/threshold-access-control)

# Getting Involved

NuCypher is a community-driven project and we're very open to outside contributions.

All our development discussions happen in our [Discord server](https://discord.gg/threshold), where we're happy to answer
technical questions, discuss feature requests,
and accept bug reports.

If you're interested in contributing code, please check out
our [Contribution Guide](CONTRIBUTING.rst)
and browse our [Open Issues](https://github.com/nucypher/nucypher/issues) for potential areas to contribute.

# Security

If you identify vulnerabilities with _any_ nucypher code, please email security@nucypher.com with relevant information
to your findings.
We will work with researchers to coordinate vulnerability disclosure between our stakers, partners, and users to ensure
successful mitigation of vulnerabilities.

Throughout the reporting process, we expect researchers to honor an embargo period that may vary depending on the
severity of the disclosure.
This ensures that we have the opportunity to fix any issues, identify further issues (if any), and inform our users.

Sometimes vulnerabilities are of a more sensitive nature and require extra precautions.
We are happy to work together to use a more secure medium, such as Signal.
Email security@nucypher.com and we will coordinate a communication channel that we're both comfortable with.

A great place to begin your research is by working on our testnet.
Please see our [documentation](https://docs.threshold.network) to get started.
We ask that you please respect testnet machines and their owners.
If you find a vulnerability that you suspect has given you access to a machine against the owner's permission, stop what
you're doing and immediately email security@nucypher.com.
